Jirafs
======

.. image:: https://travis-ci.org/coddingtonbear/jirafs.svg?branch=master
    :target: https://travis-ci.org/coddingtonbear/jirafs

.. image:: https://badge.fury.io/py/jirafs.png
    :target: http://badge.fury.io/py/jirafs

.. image:: https://pypip.in/d/jirafs/badge.png
    :target: https://pypi.python.org/pypi/jirafs

Pronounced like 'giraffes', but totally unrelated to wildlife, this
library lets you stay out of JIRA as much as possible by letting
you edit your JIRA issues as text files using an interface
modeled off of ``git`` and ``hg``.

::

    jirafs clone http://my-jira-server/browse/MYISSUE-1024
    cd MYISSUE-1024

    # let's add an attachment
    cp ~/Desktop/some_file.jpg  .

    # and add a comment
    echo 'Uploading some file I found' >> new_comment.jira

    jirafs commit
    jirafs push

    # Now your comment and file are available in JIRA

- Documentation for Jirafs is available on
  `ReadTheDocs <http://jirafs.readthedocs.org/>`_.
- Please post issues on
  `Github <http://github.com/coddingtonbear/jirafs/issues>`_.
- Test status available on
  `Travis-CI <https://travis-ci.org/coddingtonbear/jirafs>`_.

